=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2009-05-28 08:17:40 +0000
+++ loggerhead/apps/branch.py	2009-10-17 06:35:33 +0000
@@ -52,7 +52,7 @@
         self._config = config
         self.friendly_name = friendly_name
         self.branch_link = branch_link  # Currently only used in Launchpad
-        self.log = logging.getLogger('loggerhead.%s' % friendly_name)
+        self.log = logging.getLogger('loggerhead.%s' % (friendly_name,))
         if graph_cache is None:
             graph_cache = bzrlib.lru_cache.LRUCache(10)
         self.graph_cache = graph_cache
@@ -86,7 +86,7 @@
         qs = []
         for k, v in kw.iteritems():
             if v is not None:
-                qs.append('%s=%s'%(k, urllib.quote(v)))
+                qs.append('%s=%s' % (k, urllib.quote(v)))
         qs = '&'.join(qs)
         return request.construct_url(
             self._environ, script_name=self._url_base,

=== modified file 'loggerhead/apps/transport.py'
--- loggerhead/apps/transport.py	2009-07-07 23:52:24 +0000
+++ loggerhead/apps/transport.py	2009-10-17 06:35:33 +0000
@@ -54,10 +54,13 @@
             name = self.name
             is_root = False
         branch_app = BranchWSGIApp(
-            branch, name,
+            branch,
+            name,
             {'cachepath': self._config.SQL_DIR},
-            self.root.graph_cache, is_root=is_root,
-            use_cdn=self._config.get_option('use_cdn'))
+            self.root.graph_cache,
+            is_root=is_root,
+            use_cdn=self._config.get_option('use_cdn'),
+            )
         return branch_app.app
 
     def app_for_non_branch(self, environ):

=== modified file 'loggerhead/config.py'
--- loggerhead/config.py	2009-10-17 06:19:40 +0000
+++ loggerhead/config.py	2009-10-17 06:35:33 +0000
@@ -37,7 +37,7 @@
         sql_dir=None,
         allow_writes=False,
         )
-    parser.add_option("--user-dirs", action="store_true", dest="user_dirs",
+    parser.add_option("--user-dirs", action="store_true",
                       help="Serve user directories as ~user.")
     parser.add_option("--trunk-dir", metavar="DIR",
                       help="The directory that contains the trunk branches.")
@@ -47,18 +47,17 @@
     parser.add_option("--host", dest="user_host",
                       help="Host Loggerhead should listen on.")
     parser.add_option('--memory-profile', action='store_true',
-                      dest='memory_profile',
                       help='Profile the memory usage using Dozer.')
     parser.add_option("--prefix", dest="user_prefix",
                       help="Specify host prefix.")
-    parser.add_option("--profile", action="store_true", dest="profile",
+    parser.add_option("--profile", action="store_true",
                       help="Generate callgrind profile data to "
                         "%d-stats.callgrind on each request.")
-    parser.add_option("--reload", action="store_true", dest="reload",
+    parser.add_option("--reload", action="store_true",
                       help="Restarts the application when changing python"
                            " files. Only used for development purposes.")
-    parser.add_option('--log-folder', dest="log_folder",
-                      type=str, help="The directory to place log files in.")
+    parser.add_option('--log-folder',
+                      help="The directory to place log files in.")
     parser.add_option("--version", action="store_true", dest="show_version",
                       help="Print the software version and exit")
     parser.add_option("--use-cdn", action="store_true", dest="use_cdn",
@@ -108,4 +107,3 @@
     def arg_count(self):
         """Return the number of args from the option parser."""
         return len(self._args)
-

=== modified file 'loggerhead/controllers/annotate_ui.py'
--- loggerhead/controllers/annotate_ui.py	2009-05-16 06:05:56 +0000
+++ loggerhead/controllers/annotate_ui.py	2009-10-17 06:35:33 +0000
@@ -62,10 +62,10 @@
         try:
             bzrlib.textfile.check_text_lines(file_lines)
         except bzrlib.errors.BinaryFile:
-                # bail out; this isn't displayable text
-                yield util.Container(parity=0, lineno=1, status='same',
-                                     text='(This is a binary file.)',
-                                     change=util.Container())
+            # bail out; this isn't displayable text
+            yield util.Container(parity=0, lineno=1, status='same',
+                                 text='(This is a binary file.)',
+                                 change=util.Container())
         else:
             if highlight is not None:
                 hl_lines = highlight(file_name, file_text, encoding)
@@ -95,7 +95,7 @@
                     change=change, text=hl_lines[lineno - 1])
                 lineno += 1
 
-        self.log.debug('annotate: %r secs' % (time.time() - z))
+        self.log.debug('annotate: %r secs' % (time.time() - z,))
 
     def get_values(self, path, kwargs, headers):
         history = self._history

=== modified file 'loggerhead/controllers/diff_ui.py'
--- loggerhead/controllers/diff_ui.py	2008-12-05 18:52:44 +0000
+++ loggerhead/controllers/diff_ui.py	2009-05-13 14:03:48 +0000
@@ -73,7 +73,7 @@
         headers = [
             ('Content-Type', 'application/octet-stream'),
             ('Content-Length', len(content)),
-            ('Content-Disposition', 'attachment; filename=%s' % filename),
+            ('Content-Disposition', 'attachment; filename=%s' % (filename,)),
             ]
         start_response('200 OK', headers)
         return [content]

=== modified file 'loggerhead/controllers/directory_ui.py'
--- loggerhead/controllers/directory_ui.py	2009-06-02 13:39:33 +0000
+++ loggerhead/controllers/directory_ui.py	2009-10-17 06:35:33 +0000
@@ -57,7 +57,7 @@
             def static_url(path):
                 return self._static_url_base + path
         self._branch = _branch
-        self._history_callable = lambda:None
+        self._history_callable = lambda: None
         self._name = name
         self._static_url_base = static_url_base
         self.transport = transport

=== modified file 'loggerhead/controllers/download_ui.py'
--- loggerhead/controllers/download_ui.py	2009-07-07 23:52:24 +0000
+++ loggerhead/controllers/download_ui.py	2009-10-17 06:35:33 +0000
@@ -63,7 +63,7 @@
             ('Content-Type', mime_type),
             ('Content-Length', len(content)),
             ('Content-Disposition',
-             'attachment; filename*=utf-8\'\'%s' % encoded_filename),
+             'attachment; filename*=utf-8\'\'%s' % (encoded_filename,)),
             ]
         start_response('200 OK', headers)
         return [content]

=== modified file 'loggerhead/daemon.py'
--- loggerhead/daemon.py	2008-12-07 15:24:05 +0000
+++ loggerhead/daemon.py	2009-05-13 14:03:48 +0000
@@ -53,7 +53,7 @@
             pass
 
     f = open(pidfile, 'w')
-    f.write('%d\n' % os.getpid())
+    f.write('%d\n' % (os.getpid(),))
     f.close()
 
 

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2009-10-17 06:19:40 +0000
+++ loggerhead/history.py	2009-10-17 06:35:33 +0000
@@ -34,10 +34,10 @@
 import re
 import textwrap
 
-import bzrlib
 import bzrlib.branch
 import bzrlib.delta
 import bzrlib.errors
+import bzrlib.revision
 
 from loggerhead import search
 from loggerhead import util
@@ -104,6 +104,7 @@
         return len(self.revid_list)
 
 class FileChangeReporter(object):
+
     def __init__(self, old_inv, new_inv):
         self.added = []
         self.modified = []
@@ -187,7 +188,7 @@
         self._cache[key] = (revid, data)
 
 
-class History (object):
+class History(object):
     """Decorate a branch to provide information for rendering.
 
     History objects are expected to be short lived -- when serving a request
@@ -261,7 +262,7 @@
         self._branch = branch
         self._inventory_cache = {}
         self._branch_nick = self._branch.get_config().get_nickname()
-        self.log = logging.getLogger('loggerhead.%s' % self._branch_nick)
+        self.log = logging.getLogger('loggerhead.%s' % (self._branch_nick,))
 
         self.last_revid = branch.last_revision()
 
@@ -691,8 +692,8 @@
             text_changes: list((filename, file_id)),
         """
         repo = self._branch.repository
-        if bzrlib.revision.is_null(old_revid) or \
-               bzrlib.revision.is_null(new_revid):
+        if (bzrlib.revision.is_null(old_revid) or
+            bzrlib.revision.is_null(new_revid)):
             old_tree, new_tree = map(
                 repo.revision_tree, [old_revid, new_revid])
         else:

=== modified file 'loggerhead/main.py'
--- loggerhead/main.py	2009-07-07 23:52:24 +0000
+++ loggerhead/main.py	2009-10-17 06:35:33 +0000
@@ -39,7 +39,7 @@
     config = LoggerheadConfig(args)
 
     if config.get_option('show_version'):
-        print "loggerhead %s" % __version__
+        print "loggerhead %s" % (__version__,)
         sys.exit(0)
 
     if config.arg_count > 1:

=== modified file 'loggerhead/middleware/profile.py'
--- loggerhead/middleware/profile.py	2009-06-26 18:38:37 +0000
+++ loggerhead/middleware/profile.py	2009-10-17 06:35:33 +0000
@@ -4,6 +4,7 @@
 
 from bzrlib.lsprof import profile
 
+
 class LSProfMiddleware(object):
     """Paste middleware for profiling with lsprof."""
 

=== modified file 'loggerhead/search.py'
--- loggerhead/search.py	2009-04-17 01:50:05 +0000
+++ loggerhead/search.py	2009-04-17 03:38:04 +0000
@@ -17,6 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+
 _mod_index = None
 def import_search():
     global errors, _mod_index, FileTextHit, RevisionHit

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2009-10-17 06:19:40 +0000
+++ loggerhead/util.py	2009-10-17 06:35:33 +0000
@@ -314,7 +314,7 @@
 
     out = str(base)
     if (base < 100) and (dot != 0):
-        out += '.%d' % (dot)
+        out += '.%d' % (dot,)
     if divisor == KILO:
         out += 'K'
     elif divisor == MEG:
@@ -461,7 +461,7 @@
         now = time.time()
         msec = int(now * 1000) % 1000
         timestr = time.strftime('%Y%m%d%H%M%S',
-                                time.localtime(now)) + ('%03d' % msec)
+                                time.localtime(now)) + ('%03d' % (msec,))
         filename = f.__name__ + '-' + timestr + '.lsprof'
         cPickle.dump(stats, open(filename, 'w'), 2)
         return ret
@@ -533,7 +533,7 @@
     _reloader_environ_key = 'PYTHON_RELOADER_SHOULD_RUN'
 
     @classmethod
-    def _turn_sigterm_into_systemexit(self):
+    def _turn_sigterm_into_systemexit(cls):
         """
         Attempts to turn a SIGTERM exception into a SystemExit exception.
         """
@@ -547,26 +547,26 @@
         signal.signal(signal.SIGTERM, handle_term)
 
     @classmethod
-    def is_installed(self):
-        return os.environ.get(self._reloader_environ_key)
+    def is_installed(cls):
+        return os.environ.get(cls._reloader_environ_key)
 
     @classmethod
-    def install(self):
+    def install(cls):
         from paste import reloader
         reloader.install(int(1))
 
     @classmethod
-    def restart_with_reloader(self):
+    def restart_with_reloader(cls):
         """Based on restart_with_monitor from paste.script.serve."""
         print 'Starting subprocess with file monitor'
-        while 1:
+        while True:
             args = [sys.executable] + sys.argv
             new_environ = os.environ.copy()
-            new_environ[self._reloader_environ_key] = 'true'
+            new_environ[cls._reloader_environ_key] = 'true'
             proc = None
             try:
                 try:
-                    self._turn_sigterm_into_systemexit()
+                    cls._turn_sigterm_into_systemexit()
                     proc = subprocess.Popen(args, env=new_environ)
                     exit_code = proc.wait()
                     proc = None
@@ -575,7 +575,7 @@
                     return 1
             finally:
                 if (proc is not None
-                    and hasattr(os, 'kill')):
+                    and getattr(os, 'kill', None) is not None):
                     import signal
                     try:
                         os.kill(proc.pid, signal.SIGTERM)

=== modified file 'loggerhead/wholehistory.py'
--- loggerhead/wholehistory.py	2009-10-15 23:12:10 +0000
+++ loggerhead/wholehistory.py	2009-10-17 06:35:33 +0000
@@ -48,7 +48,7 @@
     last_revid = branch.last_revision()
 
     log = logging.getLogger('loggerhead.%s' %
-                            branch.get_config().get_nickname())
+                            (branch.get_config().get_nickname(),))
 
     graph = branch.repository.get_graph()
     parent_map = dict(((key, value) for key, value in

=== modified file 'start-loggerhead'
--- start-loggerhead	2009-06-08 23:02:49 +0000
+++ start-loggerhead	2009-10-17 06:35:33 +0000
@@ -20,7 +20,6 @@
 
 
 import logging
-import logging.handlers
 from optparse import OptionParser
 import os
 import sys
@@ -35,7 +34,7 @@
 
 from loggerhead import daemon
 from loggerhead.apps.config import Root
-from loggerhead.trace import make_handler, setup_logging
+from loggerhead.trace import setup_logging
 from loggerhead.apps.error import ErrorHandlerApp
 
 
@@ -103,7 +102,7 @@
     if not options.foreground:
         sys.stderr.write('\n')
         sys.stderr.write('Launching loggerhead into the background.\n')
-        sys.stderr.write('PID file: %s\n' % options.pidfile)
+        sys.stderr.write('PID file: %s\n' % (options.pidfile,))
         sys.stderr.write('\n')
 
         daemon.daemonize(options.pidfile, home)

=== modified file 'stop-loggerhead'
--- stop-loggerhead	2008-10-24 02:26:05 +0000
+++ stop-loggerhead	2009-05-13 14:03:48 +0000
@@ -32,7 +32,7 @@
 try:
     f = open(options.pidfile, 'r')
 except IOError, e:
-    print 'Pid file %s not found.' % options.pidfile
+    print 'Pid file %s not found.' % (options.pidfile,)
     sys.exit(1)
 
 pid = int(f.readline())
@@ -44,7 +44,7 @@
     sys.exit(1)
 
 print
-print 'Shutting down previous server @ pid %d.' % pid
+print 'Shutting down previous server @ pid %d.' % (pid,)
 print
 
 import signal

